//--------------------------------------------------------------------------
// Large Inventory Station
//
//
//--------------------------------------------------------------------------

datablock StaticShapeData(DeployedBarracks) : StaticShapeDamageProfile {
	className = "Barracks";
	shapeFile = "station_inv_human.dts"; // dmiscf.dts, alternate
	maxDamage = 2.0;
	destroyedLevel = 2.0;
	disabledLevel = 2.0;
	mass = 1.2;
	elasticity = 0.1;
	friction = 0.9;
	collideable = 1;
	pickupRadius = 1;
	sticky=false;

	impulse = 5000;

	hasLight = true;
	lightType = "PulsingLight";
	lightColor = "0.1 0.8 0.8 1.0";
	lightTime = "100";
	lightRadius = "3";

	explosion      = HandGrenadeExplosion;
	expDmgRadius = 3.0;
	expDamage = 0.1;
	expImpulse = 200.0;
	dynamicType = $TypeMasks::StaticShapeObjectType;
	deployedObject = true;
	cmdCategory = "DSupport";
	cmdIcon = CMDSensorIcon;
	cmdMiniIconName = "commander/MiniIcons/com_deploymotionsensor";

	targetNameTag = 'Barracks / Hand Of Nod'; //this changes
	targetTypeTag = '';
	deployAmbientThread = true;
	debrisShapeName = "debris_generic_small.dts";
	debris = DeployableDebris;
	heatSignature = 0;
};


datablock ShapeBaseImageData(BarracksDeployableImage) {
   mass = 1;
   emap = true;
   shapeFile = "stackable1s.dts";
   item = BarracksDeployable;
   mountPoint = 1;
   offset = "0 0 0";
   deployed = DeployedBarracks;
   heatSignature = 0;

   stateName[0] = "Idle";
   stateTransitionOnTriggerDown[0] = "Activate";

   stateName[1] = "Activate";
   stateScript[1] = "onActivate";
   stateTransitionOnTriggerUp[1] = "Idle";

   isLarge = true;
   maxDepSlope = 360;
   deploySound = ItemPickupSound;

   minDeployDis = 0.5;
   maxDeployDis = 5.0;
};

datablock ItemData(BarracksDeployable)
{
   className = Pack;
   catagory = "Deployables";
   shapeFile = "stackable1s.dts";
   mass = 1;
   elasticity = 0.2;
   friction = 0.6;
   pickupRadius = 1;
   rotate = true;
   image = "BarracksDeployableImage";
   joint = "4.5 4.5 4.5";
   pickUpName = "a barracks pack";
   heatSignature = 0;
   emap = true;
};

function BarracksDeployable::onPickup(%this, %obj, %shape, %amount)
{
   // created to prevent console errors
}

function BarracksDeployableImage::onDeploy(%item, %plyr, %slot) {

    if($BuildingCount::PowerPlant[%plyr.client.team] <= 0) {
    messageclient(%plyr.client, 'MsgClient', '\c5Tech Error, Power Plant Required.');
    return;
    }

	%className = "StaticShape";
	%plyr.unMountImage(%slot);
	%plyr.decInventory(%item.item,1);
	%grounded = 0;
	if (%item.surface.getClassName() $= TerrainBlock)
		%grounded = 1;

	%playerVector = vectorNormalize(-1 * getWord(%plyr.getEyeVector(),1) SPC getWord(%plyr.getEyeVector(),0) SPC "0");

	if (vAbs(floorVec(%item.surfaceNrm,100)) $= "0 0 1")
		%item.surfaceNrm2 = vectorScale(%playerVector,-1);
	else
		%item.surfaceNrm2 = vectorNormalize(vectorCross(%item.surfaceNrm,"0 0 1"));

	%rot = fullRot(%item.surfaceNrm,%item.surfaceNrm2);

   %deplObj = new (%className)()  //Inventory Station
   {
	dataBlock = DeployedBarracks;
	position = %surfacePt;
	rotation = %rot;
	deployed = true;
   };
   %deplObj.setTransform(%item.surfacePt SPC %rot);
	%deplObj.team = %plyr.client.Team;
   %deplObj.team.BarracksCount++;
   
    if(%deplObj.team == 1 || %deplObj.team == 3 || %deplObj.team == 6) {
	setTargetName(%deplObj.target,addTaggedString("Barracks"));
    }
    else {
	setTargetName(%deplObj.target,addTaggedString("Hand Of NOD"));
    }
    $BuildingCount::Barracks[%deplObj.team]++;
    %deplObj.counter = $BuildingCount::Barracks[%deplObj.team];
    $CNC::BarracksBuilding[%deplObj.team,%deplObj.counter] = %deplObj;

	addDSurface(%item.surface,%deplObj);

	// set power frequency
	%deplObj.powerFreq = %plyr.powerFreq;

   if(%deplObj.getTarget() != -1)
      setTargetSensorGroup(%deplObj.getTarget(), %plyr.client.team);

   // place the deployable in the MissionCleanup/Deployables group (AI reasons)

   addToDeployGroup(%deplObj);

   //let the AI know as well...

   AIDeployObject(%plyr.client, %deplObj);

   // play the deploy sound
   serverPlay3D(%item.deploySound, %deplObj.getTransform());

   // increment the team count for this deployed object

   $TeamDeployedCount[%plyr.team, %item.item]++;

   %deplObj.deploy();

	// Adjust the trigger object
	adjustTrigger(%deplObj);

      %count = ClientGroup.getCount();
      for(%i = 0; %i < %count; %i++) {
         %cl = ClientGroup.getObject(%i);
         if(%cl.team == %deplObj.team) {
            if(%deplObj.team == 1 || %deplObj.team == 3 || %deplObj.team == 6)
            messageclient(%cl, 'MsgClient', "\c5Base Update: Construction Complete, Barracks.");
            else
            messageclient(%cl, 'MsgClient', "\c5Base Update: Construction Complete, Hand Of Nod.");
         }
      }


   return %deplObj;
}

function DeployedBarracks::onDestroyed(%this,%obj,%prevState) {

      %count = ClientGroup.getCount();
      for(%i = 0; %i < %count; %i++) {
         %cl = ClientGroup.getObject(%i);
         if(%cl.team == %obj.team) {
            if(%obj.team == 1 || %obj.team == 3 || %obj.team == 6)
            messageclient(%cl, 'MsgClient', "\c5Base Update: Building Lost, Barracks.");
            else
            messageclient(%cl, 'MsgClient', "\c5Base Update: Building Lost, Hand Of Nod.");
         }
      }
   //kill the obj spawn
   $CNC::BarracksBuilding[%obj.team,%obj.counter] = "";
   $BuildingCount::Barracks[%obj.team]--;
   $TeamDeployedCount[%obj.team,BarracksDeployable]--;
   %obj.team.BarracksCount--;
   remDSurface(%obj);
   %obj.schedule(500,"delete");
   Parent::onDestroyed(%data,%obj,%prevState);
}

function BarracksDeployableImage::testNoTerrainFound(%item)
{
//return %item.surface.getClassName() !$= TerrainBlock;
}

function BarracksDeployableImage::onMount(%data, %obj, %node) {

}
