//--------------------------------------------------------------------------
// Deployable Generator
//--------------------------------------------------------------------------

datablock StaticShapeData(DeployedPowerPlant) : StaticShapeDamageProfile {
	className = "PowerPlant";
	shapeFile = "station_generator_large.dts"; // dmiscf.dts, alternate
	maxDamage = 2.0;
	destroyedLevel = 2.0;
	disabledLevel = 2.0;
	mass = 1.2;
	elasticity = 0.1;
	friction = 0.9;
	collideable = 1;
	pickupRadius = 1;
	sticky=false;

	impulse = 5000;

	hasLight = true;
	lightType = "PulsingLight";
	lightColor = "0.1 0.8 0.8 1.0";
	lightTime = "100";
	lightRadius = "3";

	explosion      = HandGrenadeExplosion;
	expDmgRadius = 3.0;
	expDamage = 0.1;
	expImpulse = 200.0;
	dynamicType = $TypeMasks::StaticShapeObjectType;
	deployedObject = true;
	cmdCategory = "DSupport";
	cmdIcon = CMDSensorIcon;
	cmdMiniIconName = "commander/MiniIcons/com_deploymotionsensor";

	targetNameTag = 'Power Plant';
	targetTypeTag = '';
	deployAmbientThread = true;
	debrisShapeName = "debris_generic_small.dts";
	debris = DeployableDebris;
	heatSignature = 0;
};


datablock ShapeBaseImageData(PowerPlantImage) {
	mass = 20;
	emap = true;
	shapeFile = "stackable1s.dts";
	item = PowerPlantDeployable;
	mountPoint = 1;
	offset = "0 0 0";
	deployed = DeployedPowerPlant;
	heatSignature = 0;

	stateName[0] = "Idle";
	stateTransitionOnTriggerDown[0] = "Activate";

	stateName[1] = "Activate";
	stateScript[1] = "onActivate";
	stateTransitionOnTriggerUp[1] = "Idle";

	isLarge = true;
	maxDepSlope = 360;
	deploySound = ItemPickupSound;

	minDeployDis = 2;
	maxDeployDis = 5;
};

datablock ItemData(PowerPlantDeployable) {
	className = Pack;
	catagory = "Deployables";
	shapeFile = "stackable1s.dts";
	mass = 5.0;

	hasLight = true;
	lightType = "PulsingLight";
	lightColor = "0.1 0.8 0.8 1.0";
	lightTime = "1000";
	lightRadius = "3";

	elasticity = 0.2;
	friction = 0.6;
	pickupRadius = 3;
	rotate = true;
	image = "PowerPlantImage";
	pickUpName = "a Power Plant";
	heatSignature = 0;
	emap = true;
};

function PowerPlantImage::testNoTerrainFound(%item) {
	// don't check this for non-Landspike turret deployables
}

function PowerPlantDeployable::onPickup(%this, %obj, %shape, %amount) {
	// created to prevent console errors
}

function PowerPlantImage::onDeploy(%item, %plyr, %slot) {

	%className = "StaticShape";

	%playerVector = vectorNormalize(getWord(%plyr.getEyeVector(),1) SPC -1 * getWord(%plyr.getEyeVector(),0) SPC "0");

	if (vAbs(floorVec(%item.surfaceNrm,100)) $= "0 0 1")
		%item.surfaceNrm2 = vectorScale(%playerVector,-1);
	else
		%item.surfaceNrm2 = vectorNormalize(vectorCross(%item.surfaceNrm,"0 0 1"));

	%rot = fullRot(%item.surfaceNrm,%item.surfaceNrm2);

	%item.surfacePt = vectorAdd(%item.surfacePt,vectorScale(vectorNormalize(vectorCross(%item.surfaceNrm,%item.surfaceNrm2)),2));

	%deplObj = new (%className)() {
		dataBlock = DeployedPowerPlant;
		deployed = true;
	};

	// set orientation
	%deplObj.setTransform(%item.surfacePt SPC %rot);

	// set team, owner, and handle
	%deplObj.team = %plyr.client.Team;

	// set power frequency
	%deplObj.powerFreq = %plyr.powerFreq;
	setTargetName(%deplObj.target,addTaggedString("Power Plant"));

	// set power
	%deplObj.setSelfPowered();

	// set the sensor group if it needs one
	if (%deplObj.getTarget() != -1)
		setTargetSensorGroup(%deplObj.getTarget(), %plyr.client.team);

	// place the deployable in the MissionCleanup/Deployables group (AI reasons)
	addToDeployGroup(%deplObj);

	//let the AI know as well...
	AIDeployObject(%plyr.client, %deplObj);

	// play the deploy sound
	serverPlay3D(%item.deploySound, %deplObj.getTransform());

	// increment the team count for this deployed object
	$TeamDeployedCount[%plyr.team, %item.item]++;

	addDSurface(%item.surface,%deplObj);

	%deplObj.playThread($PowerThread,"Power");
 
    $BuildingCount::PowerPlant[%deplObj.team]++;
    $Power[%deplObj.team] = $Power[%deplObj.team] + 250; //Add 250 Power From The Team Count
    %deplObj.team.PowerPlantCount++;

	// take the deployable off the player's back and out of inventory
	%plyr.unmountImage(%slot);
	%plyr.decInventory(%item.item, 1);

	// add to power list
	$PowerList = listAdd($PowerList,%deplObj,-1);
 
      %count = ClientGroup.getCount();
      for(%i = 0; %i < %count; %i++) {
         %cl = ClientGroup.getObject(%i);
         if(%cl.team == %deplObj.team) {
         messageclient(%cl, 'MsgClient', "\c5Base Update: Construction Complete, Power Plant.");
         }
      }
	
	return %deplObj;
}

function DeployedPowerPlant::onDestroyed(%this,%obj,%prevState) {

      %count = ClientGroup.getCount();
      for(%i = 0; %i < %count; %i++) {
         %cl = ClientGroup.getObject(%i);
         if(%cl.team == %obj.team) {
         messageclient(%cl, 'MsgClient', "\c5Base Update: Building Lost, Power Plant.");
         }
      }

    $BuildingCount::PowerPlant[%obj.team]--;
   $TeamDeployedCount[%obj.team,PowerPlantDeployable]--;
   $Power[%obj.team] = $Power[%obj.team] - 250; //Remove 250 Power From The Team Count
   %obj.team.PowerPlantCount--;
   remDSurface(%obj);
   %obj.schedule(500,"delete");
   Parent::onDestroyed(%data,%obj,%prevState);
}

function PowerPlantImage::onMount(%data,%obj,%node) {
	%obj.hasGen = true; // set for gencheck
}

function PowerPlantImage::onUnmount(%data,%obj,%node) {
	%obj.hasGen = "";
}
