//--------------------------------------------------------------------------
// Deployable Generator
//--------------------------------------------------------------------------

datablock StaticShapeData(DeployedTargetingBeacon) : StaticShapeDamageProfile {
	className = "TargetingBeacon";
	shapeFile = "sensor_pulse_large.dts"; // dmiscf.dts, alternate
	maxDamage = 1.0;
	destroyedLevel = 1.0;
	disabledLevel = 1.0;
	mass = 1.2;
	elasticity = 0.1;
	friction = 0.9;
	collideable = 1;
	pickupRadius = 1;
	sticky=false;

	impulse = 5000;

	hasLight = true;
	lightType = "PulsingLight";
	lightColor = "0.1 0.8 0.8 1.0";
	lightTime = "100";
	lightRadius = "3";

	explosion      = HandGrenadeExplosion;
	expDmgRadius = 3.0;
	expDamage = 0.1;
	expImpulse = 200.0;
	dynamicType = $TypeMasks::StaticShapeObjectType;
	deployedObject = true;
	cmdCategory = "DSupport";
	cmdIcon = CMDSensorIcon;
	cmdMiniIconName = "commander/MiniIcons/com_deploymotionsensor";

	targetNameTag = 'Targeting Beacon';
	targetTypeTag = '';
	deployAmbientThread = true;
	debrisShapeName = "debris_generic_small.dts";
	debris = DeployableDebris;
	heatSignature = 0;
};


datablock ShapeBaseImageData(TargetingBeaconImage) {
	mass = 20;
	emap = true;
	shapeFile = "stackable1s.dts";
	item = TargetingBeaconDeployable;
	mountPoint = 1;
	offset = "0 0 0";
	deployed = DeployedTargetingBeacon;
	heatSignature = 0;

	stateName[0] = "Idle";
	stateTransitionOnTriggerDown[0] = "Activate";

	stateName[1] = "Activate";
	stateScript[1] = "onActivate";
	stateTransitionOnTriggerUp[1] = "Idle";

	isLarge = false;
	maxDepSlope = 360;
	deploySound = ItemPickupSound;

	minDeployDis = 2;
	maxDeployDis = 5;
};

datablock ItemData(TargetingBeaconDeployable) {
	className = Pack;
	catagory = "Deployables";
	shapeFile = "stackable1s.dts";
	mass = 5.0;

	hasLight = true;
	lightType = "PulsingLight";
	lightColor = "0.1 0.8 0.8 1.0";
	lightTime = "1000";
	lightRadius = "3";

	elasticity = 0.2;
	friction = 0.6;
	pickupRadius = 3;
	rotate = true;
	image = "TargetingBeaconImage";
	pickUpName = "a Power Plant";
	heatSignature = 0;
	emap = true;
};

function TargetingBeaconImage::testNoTerrainFound(%item) {
	// don't check this for non-Landspike turret deployables
}

function TargetingBeaconDeployable::onPickup(%this, %obj, %shape, %amount) {
	// created to prevent console errors
}

function TargetingBeaconImage::onDeploy(%item, %plyr, %slot) {

	%className = "StaticShape";

	%playerVector = vectorNormalize(getWord(%plyr.getEyeVector(),1) SPC -1 * getWord(%plyr.getEyeVector(),0) SPC "0");

	if (vAbs(floorVec(%item.surfaceNrm,100)) $= "0 0 1")
		%item.surfaceNrm2 = vectorScale(%playerVector,-1);
	else
		%item.surfaceNrm2 = vectorNormalize(vectorCross(%item.surfaceNrm,"0 0 1"));

	%rot = fullRot(%item.surfaceNrm,%item.surfaceNrm2);

	%item.surfacePt = vectorAdd(%item.surfacePt,vectorScale(vectorNormalize(vectorCross(%item.surfaceNrm,%item.surfaceNrm2)),2));

	%deplObj = new (%className)() {
		dataBlock = DeployedTargetingBeacon;
        scale = "0.3 0.3 0.3";
		deployed = true;
	};

	// set orientation
	%deplObj.setTransform(%item.surfacePt SPC %rot);

	// set team, owner, and handle
	%deplObj.team = %plyr.client.Team;

	// set power frequency
	%deplObj.powerFreq = %plyr.powerFreq;
    if(%deplObj.team == 1 || %deplObj.team == 3 || %deplObj.team == 6) {
	setTargetName(%deplObj.target,addTaggedString("Ion Cannon Targeter"));
    PrepIonCannon($CNC::IonControl[%deplObj.team], %deplObj.getPosition());
    $CNC::IonControl[%deplObj.team].canFireIonCannon = 0;
    }
    else {
	setTargetName(%deplObj.target,addTaggedString("Nuclear Missile Targeter"));
    PrepNuke($CNC::TempleOfNOD[%deplObj.team], %deplObj.getPosition());
    $CNC::TempleOfNOD[%deplObj.team].canFireNuke = 0;
    }

	// set power
	%deplObj.setSelfPowered();

	// set the sensor group if it needs one
	if (%deplObj.getTarget() != -1)
		setTargetSensorGroup(%deplObj.getTarget(), %plyr.client.team);

	// place the deployable in the MissionCleanup/Deployables group (AI reasons)
	addToDeployGroup(%deplObj);

	//let the AI know as well...
	AIDeployObject(%plyr.client, %deplObj);

	// play the deploy sound
	serverPlay3D(%item.deploySound, %deplObj.getTransform());

	// increment the team count for this deployed object
	$TeamDeployedCount[%plyr.team, %item.item]++;

	addDSurface(%item.surface,%deplObj);

	%deplObj.playThread($PowerThread,"Power");

	// take the deployable off the player's back and out of inventory
	%plyr.unmountImage(%slot);
	%plyr.decInventory(%item.item, 1);

	// add to power list

	return %deplObj;
}

function DeployedTargetingBeacon::onDestroyed(%this,%obj,%prevState) {
   remDSurface(%obj);
   %obj.schedule(500,"delete");
   $TeamDeployedCount[%obj.team,TargetingBeaconDeployable]--;
   Parent::onDestroyed(%data,%obj,%prevState);
}

function TargetingBeaconImage::onMount(%data,%obj,%node) {
	%obj.hasGen = true; // set for gencheck
}

function TargetingBeaconImage::onUnmount(%data,%obj,%node) {
	%obj.hasGen = "";
}
