datablock StaticShapeData(DeployedWeaponsFactory) : StaticShapeDamageProfile
{
   className = Station;
   shapeFile = "station_teleport.dts";
   maxDamage = 2.50;
   destroyedLevel = 2.50;
   disabledLevel = 2.35;
   explosion      = DeployablesExplosion;
      expDmgRadius = 15.0;
      expDamage = 0.65;
      expImpulse = 1500.0;

   dynamicType = $TypeMasks::StationObjectType;
   isShielded = false;
   energyPerDamagePoint = 110;
   maxEnergy = 50;
   rechargeRate = 0.20;
   renderWhenDestroyed = false;

   deployedObject = true;

   cmdCategory = "DSupport";
   cmdIcon = CMDStationIcon;
   cmdMiniIconName = "commander/MiniIcons/com_inventory_grey";
   targetNameTag = 'Weapons Factory';
   targetTypeTag = '';

   debrisShapeName = "debris_generic_small.dts";
   debris = DeployableDebris;
   heatSignature = 0;
   needspower = true;
};

datablock ShapeBaseImageData(WeaponsFactoryDeployableImage) {
   mass = 1;
   emap = true;
   shapeFile = "stackable1s.dts";
   item = WeaponsFactoryDeployable;
   mountPoint = 1;
   offset = "0 0 0";
   deployed = DeployedWeaponsFactory;
   heatSignature = 0;

   stateName[0] = "Idle";
   stateTransitionOnTriggerDown[0] = "Activate";

   stateName[1] = "Activate";
   stateScript[1] = "onActivate";
   stateTransitionOnTriggerUp[1] = "Idle";

   isLarge = true;
   maxDepSlope = 360;
   deploySound = ItemPickupSound;

   minDeployDis = 0.5;
   maxDeployDis = 5.0;
};

datablock ItemData(WeaponsFactoryDeployable)
{
   className = Pack;
   catagory = "Deployables";
   shapeFile = "stackable1s.dts";
   mass = 1;
   elasticity = 0.2;
   friction = 0.6;
   pickupRadius = 1;
   rotate = true;
   image = "WeaponsFactoryDeployableImage";
   joint = "4.5 4.5 4.5";
   pickUpName = "a WeaponsFactory pack";
   heatSignature = 0;
   emap = true;
};

function WeaponsFactoryDeployable::onPickup(%this, %obj, %shape, %amount)
{
   // created to prevent console errors
}

function WeaponsFactoryDeployableImage::onDeploy(%item, %plyr, %slot) {

    if($BuildingCount::PowerPlant[%plyr.client.team] <= 0) {
    messageclient(%plyr.client, 'MsgClient', '\c5Tech Error, Power Plant Required.');
    return;
    }
    if($BuildingCount::TiberiumRefinery[%plyr.client.team] <= 0) {
    messageclient(%plyr.client, 'MsgClient', '\c5Tech Error, Tiberium Refinery Required.');
    return;
    }

	%className = "StaticShape";
	%plyr.unMountImage(%slot);
	%plyr.decInventory(%item.item,1);
	%grounded = 0;
	if (%item.surface.getClassName() $= TerrainBlock)
		%grounded = 1;

	%playerVector = vectorNormalize(-1 * getWord(%plyr.getEyeVector(),1) SPC getWord(%plyr.getEyeVector(),0) SPC "0");

	if (vAbs(floorVec(%item.surfaceNrm,100)) $= "0 0 1")
		%item.surfaceNrm2 = vectorScale(%playerVector,-1);
	else
		%item.surfaceNrm2 = vectorNormalize(vectorCross(%item.surfaceNrm,"0 0 1"));

	%rot = fullRot(%item.surfaceNrm,%item.surfaceNrm2);

   %deplObj = new (%className)()  //Inventory Station
   {
	dataBlock = DeployedWeaponsFactory;
	position = %surfacePt;
	rotation = %rot;
	scale = "4.5 4.5 1";
	deployed = true;
   };
   %deplObj.setTransform(%item.surfacePt SPC %rot);
	%deplObj.team = %plyr.client.Team;
   %deplObj.team.WeaponsFactoryCount++;

    if(%deplObj.team == 1 || %deplObj.team == 3 || %deplObj.team == 6) {
	setTargetName(%deplObj.target,addTaggedString("War Factory"));
    }
    else {
	setTargetName(%deplObj.target,addTaggedString("Weapons Factory"));
    }
    $BuildingCount::WeaponsFactory[%deplObj.team]++;

	addDSurface(%item.surface,%deplObj);

	// set power frequency
	%deplObj.powerFreq = %plyr.powerFreq;

   if(%deplObj.getTarget() != -1)
      setTargetSensorGroup(%deplObj.getTarget(), %plyr.client.team);

   // place the deployable in the MissionCleanup/Deployables group (AI reasons)

   addToDeployGroup(%deplObj);

   //let the AI know as well...

   AIDeployObject(%plyr.client, %deplObj);

   // play the deploy sound
   serverPlay3D(%item.deploySound, %deplObj.getTransform());

   // increment the team count for this deployed object

   $TeamDeployedCount[%plyr.team, %item.item]++;

   %deplObj.deploy();

	// Adjust the trigger object
	adjustTrigger(%deplObj);

      %count = ClientGroup.getCount();
      for(%i = 0; %i < %count; %i++) {
         %cl = ClientGroup.getObject(%i);
         if(%cl.team == %deplObj.team) {
            if(%deplObj.team == 1 || %deplObj.team == 3 || %deplObj.team == 6)
            messageclient(%cl, 'MsgClient', "\c5Base Update: Construction Complete, War Factory.");
            else
            messageclient(%cl, 'MsgClient', "\c5Base Update: Construction Complete, Weapons Factory.");
         }
      }


   return %deplObj;
}

function DeployedWeaponsFactory::onDestroyed(%this,%obj,%prevState) {

      %count = ClientGroup.getCount();
      for(%i = 0; %i < %count; %i++) {
         %cl = ClientGroup.getObject(%i);
         if(%cl.team == %obj.team) {
            if(%obj.team == 1 || %obj.team == 3 || %obj.team == 6)
            messageclient(%cl, 'MsgClient', "\c5Base Update: Building Lost, War Factory.");
            else
            messageclient(%cl, 'MsgClient', "\c5Base Update: Building Lost, Weapons Factory.");
         }
      }

    $BuildingCount::WeaponsFactory[%obj.team]--;
   $TeamDeployedCount[%obj.team,WeaponsFactoryDeployable]--;
   %obj.team.WeaponsFactoryCount--;
   remDSurface(%obj);
   %obj.schedule(500,"delete");
   Parent::onDestroyed(%data,%obj,%prevState);
}

function WeaponsFactoryDeployableImage::testNoTerrainFound(%item)
{
//return %item.surface.getClassName() !$= TerrainBlock;
}

function WeaponsFactoryDeployableImage::onMount(%data, %obj, %node) {

}
